==> libavg_0.8.0.orig.tar.gz: libavg-0.8.0/src/base/Profiler.cpp <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2008 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#include "Profiler.h"
#include "ThreadProfiler.h"
#include "Logger.h"

#include <sstream>
#include <iomanip>

using namespace std;
using namespace boost;

namespace avg {
    
Profiler& Profiler::get() 
{
    static Profiler s_Instance;
    return s_Instance;
}

Profiler::Profiler() 
{
}

Profiler::~Profiler() 
{
}

void Profiler::dumpFrame()
{
    AVG_TRACE(Logger::PROFILE_LATEFRAMES, "Frame Profile:");
    AVG_TRACE(Logger::PROFILE_LATEFRAMES, "");
}

void Profiler::dumpStatistics()
{
    AVG_TRACE(Logger::PROFILE, "Profile Statistics (in us):");
    
    ThreadProfilerArray::iterator it;
    for (it= m_ThreadProfilers.begin(); it != m_ThreadProfilers.end(); ++it) {
        (*it)->dumpStatistics();
    }
}

void Profiler::registerThreadProfiler(ThreadProfilerPtr pThreadProfiler)
{
    mutex::scoped_lock Lock(m_Mutex);
    m_ThreadProfilers.push_back(pThreadProfiler);
}

ThreadProfilerPtr Profiler::getThreadProfiler()
{
    mutex::scoped_lock Lock(m_Mutex);
    ThreadProfilerArray::iterator it;
    for (it= m_ThreadProfilers.begin(); it != m_ThreadProfilers.end(); ++it) {
        if ((*it)->isCurrent()) {
            return *it;
        }
    }
    return ThreadProfilerPtr();
}

}

==> libavg_1.0.1.orig.tar.gz: libavg-1.0.1/src/base/Profiler.cpp <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2008 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#include "Profiler.h"
#include "ThreadProfiler.h"
#include "Logger.h"

#include <sstream>
#include <iomanip>

using namespace std;
using namespace boost;

namespace avg {
    
Profiler& Profiler::get() 
{
    static Profiler s_Instance;
    return s_Instance;
}

Profiler::Profiler() 
{
}

Profiler::~Profiler() 
{
}

void Profiler::dumpFrame()
{
    AVG_TRACE(Logger::PROFILE_LATEFRAMES, "Frame Profile:");
    AVG_TRACE(Logger::PROFILE_LATEFRAMES, "");
}

void Profiler::dumpStatistics()
{
    AVG_TRACE(Logger::PROFILE, "Profile Statistics (in us):");
    
    ThreadProfilerArray::iterator it;
    for (it= m_ThreadProfilers.begin(); it != m_ThreadProfilers.end(); ++it) {
        (*it)->dumpStatistics();
    }
}

void Profiler::registerThreadProfiler(ThreadProfilerPtr pThreadProfiler)
{
    mutex::scoped_lock Lock(m_Mutex);
    m_ThreadProfilers.push_back(pThreadProfiler);
}

void Profiler::threadProfilerStopped(ThreadProfilerPtr pThreadProfiler)
{
    ThreadProfilerArray::iterator it = m_ThreadProfilers.begin();
    bool bFound = false;
    while (it != m_ThreadProfilers.end()) {
        if (*it == pThreadProfiler) {
            if (pThreadProfiler->getNumZones() == 0) {
                m_ThreadProfilers.erase(it); 
                ThreadProfiler::kill();
            }
            bFound = true;
            break;
        }
        ++it;
    }
    assert(bFound);
}

}
